"""Auto generated, do not edit."""
# pylint: disable=missing-class-docstring,missing-function-docstring,line-too-long
import datetime
import collections.abc
import _zivid
import zivid
import zivid._settings2_d_converter


class Settings2D:
    class Acquisition:
        def __init__(
            self,
            aperture=_zivid.Settings2D().Acquisition().Aperture().value,
            brightness=_zivid.Settings2D().Acquisition().Brightness().value,
            exposure_time=_zivid.Settings2D().Acquisition().ExposureTime().value,
            gain=_zivid.Settings2D().Acquisition().Gain().value,
        ):

            if isinstance(aperture, (float, int,)) or aperture is None:
                self._aperture = _zivid.Settings2D.Acquisition.Aperture(aperture)
            else:
                raise TypeError(
                    "Unsupported type, expected: (float, int,) or None, got {value_type}".format(
                        value_type=type(aperture)
                    )
                )
            if isinstance(brightness, (float, int,)) or brightness is None:
                self._brightness = _zivid.Settings2D.Acquisition.Brightness(brightness)
            else:
                raise TypeError(
                    "Unsupported type, expected: (float, int,) or None, got {value_type}".format(
                        value_type=type(brightness)
                    )
                )
            if (
                isinstance(exposure_time, (datetime.timedelta,))
                or exposure_time is None
            ):
                self._exposure_time = _zivid.Settings2D.Acquisition.ExposureTime(
                    exposure_time
                )
            else:
                raise TypeError(
                    "Unsupported type, expected: (datetime.timedelta,) or None, got {value_type}".format(
                        value_type=type(exposure_time)
                    )
                )
            if isinstance(gain, (float, int,)) or gain is None:
                self._gain = _zivid.Settings2D.Acquisition.Gain(gain)
            else:
                raise TypeError(
                    "Unsupported type, expected: (float, int,) or None, got {value_type}".format(
                        value_type=type(gain)
                    )
                )

        @property
        def aperture(self):
            return self._aperture.value

        @property
        def brightness(self):
            return self._brightness.value

        @property
        def exposure_time(self):
            return self._exposure_time.value

        @property
        def gain(self):
            return self._gain.value

        @aperture.setter
        def aperture(self, value):
            if isinstance(value, (float, int,)) or value is None:
                self._aperture = _zivid.Settings2D.Acquisition.Aperture(value)
            else:
                raise TypeError(
                    "Unsupported type, expected: float or  int or None, got {value_type}".format(
                        value_type=type(value)
                    )
                )

        @brightness.setter
        def brightness(self, value):
            if isinstance(value, (float, int,)) or value is None:
                self._brightness = _zivid.Settings2D.Acquisition.Brightness(value)
            else:
                raise TypeError(
                    "Unsupported type, expected: float or  int or None, got {value_type}".format(
                        value_type=type(value)
                    )
                )

        @exposure_time.setter
        def exposure_time(self, value):
            if isinstance(value, (datetime.timedelta,)) or value is None:
                self._exposure_time = _zivid.Settings2D.Acquisition.ExposureTime(value)
            else:
                raise TypeError(
                    "Unsupported type, expected: datetime.timedelta or None, got {value_type}".format(
                        value_type=type(value)
                    )
                )

        @gain.setter
        def gain(self, value):
            if isinstance(value, (float, int,)) or value is None:
                self._gain = _zivid.Settings2D.Acquisition.Gain(value)
            else:
                raise TypeError(
                    "Unsupported type, expected: float or  int or None, got {value_type}".format(
                        value_type=type(value)
                    )
                )

        def __eq__(self, other):
            if (
                self._aperture == other._aperture
                and self._brightness == other._brightness
                and self._exposure_time == other._exposure_time
                and self._gain == other._gain
            ):
                return True
            return False

        def __str__(self):
            return str(
                zivid._settings2_d_converter.to_internal_settings2_d_acquisition(self)
            )

    class Processing:
        class Color:
            class Balance:
                def __init__(
                    self,
                    blue=_zivid.Settings2D().Processing.Color.Balance().Blue().value,
                    green=_zivid.Settings2D().Processing.Color.Balance().Green().value,
                    red=_zivid.Settings2D().Processing.Color.Balance().Red().value,
                ):

                    if isinstance(blue, (float, int,)) or blue is None:
                        self._blue = _zivid.Settings2D.Processing.Color.Balance.Blue(
                            blue
                        )
                    else:
                        raise TypeError(
                            "Unsupported type, expected: (float, int,) or None, got {value_type}".format(
                                value_type=type(blue)
                            )
                        )
                    if isinstance(green, (float, int,)) or green is None:
                        self._green = _zivid.Settings2D.Processing.Color.Balance.Green(
                            green
                        )
                    else:
                        raise TypeError(
                            "Unsupported type, expected: (float, int,) or None, got {value_type}".format(
                                value_type=type(green)
                            )
                        )
                    if isinstance(red, (float, int,)) or red is None:
                        self._red = _zivid.Settings2D.Processing.Color.Balance.Red(red)
                    else:
                        raise TypeError(
                            "Unsupported type, expected: (float, int,) or None, got {value_type}".format(
                                value_type=type(red)
                            )
                        )

                @property
                def blue(self):
                    return self._blue.value

                @property
                def green(self):
                    return self._green.value

                @property
                def red(self):
                    return self._red.value

                @blue.setter
                def blue(self, value):
                    if isinstance(value, (float, int,)) or value is None:
                        self._blue = _zivid.Settings2D.Processing.Color.Balance.Blue(
                            value
                        )
                    else:
                        raise TypeError(
                            "Unsupported type, expected: float or  int or None, got {value_type}".format(
                                value_type=type(value)
                            )
                        )

                @green.setter
                def green(self, value):
                    if isinstance(value, (float, int,)) or value is None:
                        self._green = _zivid.Settings2D.Processing.Color.Balance.Green(
                            value
                        )
                    else:
                        raise TypeError(
                            "Unsupported type, expected: float or  int or None, got {value_type}".format(
                                value_type=type(value)
                            )
                        )

                @red.setter
                def red(self, value):
                    if isinstance(value, (float, int,)) or value is None:
                        self._red = _zivid.Settings2D.Processing.Color.Balance.Red(
                            value
                        )
                    else:
                        raise TypeError(
                            "Unsupported type, expected: float or  int or None, got {value_type}".format(
                                value_type=type(value)
                            )
                        )

                def __eq__(self, other):
                    if (
                        self._blue == other._blue
                        and self._green == other._green
                        and self._red == other._red
                    ):
                        return True
                    return False

                def __str__(self):
                    return str(
                        zivid._settings2_d_converter.to_internal_settings2_d_processing_color_balance(
                            self
                        )
                    )

            def __init__(
                self,
                gamma=_zivid.Settings2D().Processing.Color().Gamma().value,
                balance=None,
            ):

                if isinstance(gamma, (float, int,)) or gamma is None:
                    self._gamma = _zivid.Settings2D.Processing.Color.Gamma(gamma)
                else:
                    raise TypeError(
                        "Unsupported type, expected: (float, int,) or None, got {value_type}".format(
                            value_type=type(gamma)
                        )
                    )
                if balance is None:
                    balance = zivid.Settings2D.Processing.Color.Balance()
                if not isinstance(balance, zivid.Settings2D.Processing.Color.Balance):
                    raise TypeError(
                        "Unsupported type: {value}".format(value=type(balance))
                    )
                self._balance = balance

            @property
            def gamma(self):
                return self._gamma.value

            @property
            def balance(self):
                return self._balance

            @gamma.setter
            def gamma(self, value):
                if isinstance(value, (float, int,)) or value is None:
                    self._gamma = _zivid.Settings2D.Processing.Color.Gamma(value)
                else:
                    raise TypeError(
                        "Unsupported type, expected: float or  int or None, got {value_type}".format(
                            value_type=type(value)
                        )
                    )

            @balance.setter
            def balance(self, value):
                if not isinstance(value, zivid.Settings2D.Processing.Color.Balance):
                    raise TypeError(
                        "Unsupported type {value}".format(value=type(value))
                    )
                self._balance = value

            def __eq__(self, other):
                if self._gamma == other._gamma and self._balance == other._balance:
                    return True
                return False

            def __str__(self):
                return str(
                    zivid._settings2_d_converter.to_internal_settings2_d_processing_color(
                        self
                    )
                )

        def __init__(
            self, color=None,
        ):

            if color is None:
                color = zivid.Settings2D.Processing.Color()
            if not isinstance(color, zivid.Settings2D.Processing.Color):
                raise TypeError("Unsupported type: {value}".format(value=type(color)))
            self._color = color

        @property
        def color(self):
            return self._color

        @color.setter
        def color(self, value):
            if not isinstance(value, zivid.Settings2D.Processing.Color):
                raise TypeError("Unsupported type {value}".format(value=type(value)))
            self._color = value

        def __eq__(self, other):
            if self._color == other._color:
                return True
            return False

        def __str__(self):
            return str(
                zivid._settings2_d_converter.to_internal_settings2_d_processing(self)
            )

    @property
    def processing(self):
        return self._processing

    @property
    def acquisitions(self):
        return self._acquisitions

    @acquisitions.setter
    def acquisitions(self, value):
        if not isinstance(value, collections.abc.Iterable):
            raise TypeError("Unsupported type: {value}".format(value=type(value)))
        self._acquisitions = _convert_to_acquistions(value)

    @processing.setter
    def processing(self, value):
        if not isinstance(value, zivid.Settings2D.Processing):
            raise TypeError("Unsupported type {value}".format(value=type(value)))
        self._processing = value

    def __str__(self):
        return str(zivid._settings2_d_converter.to_internal_settings2_d(self))

    def __init__(
        self, acquisitions=None, processing=None,
    ):
        if acquisitions is None:
            acquisitions = _zivid.Settings().Acquisitions().value
        if not isinstance(acquisitions, collections.abc.Iterable):
            raise TypeError(
                "Unsupported type: {value}".format(value=type(acquisitions))
            )
        self._acquisitions = _convert_to_acquistions(acquisitions)

        if processing is None:
            processing = zivid.Settings2D.Processing()
        if not isinstance(processing, zivid.Settings2D.Processing):
            raise TypeError("Unsupported type: {value}".format(value=type(processing)))
        self._processing = processing

    def __eq__(self, other):
        if (
            self._acquisitions == other._acquisitions
            and self._processing == other._processing
        ):
            return True
        return False


def _convert_to_acquistions(inputs):
    temp = []
    for acquisition_element in inputs:
        if isinstance(acquisition_element, Settings2D.Acquisition):
            temp.append(acquisition_element)
        else:
            raise TypeError(
                "Unsupported type {type_of_acquisition_element}".format(
                    type_of_acquisition_element=type(acquisition_element)
                )
            )
    return temp



"""Auto generated, do not edit."""
# pylint: disable=missing-class-docstring,missing-function-docstring
import datetime
import _zivid
import zivid
import zivid._frame_info_converter


class FrameInfo:
    class SoftwareVersion:
        def __init__(
            self, core=_zivid.FrameInfo().SoftwareVersion().Core().value,
        ):

            if isinstance(core, (str,)):
                self._core = _zivid.FrameInfo.SoftwareVersion.Core(core)
            else:
                raise TypeError(
                    "Unsupported type, expected: (str,), got {value_type}".format(
                        value_type=type(core)
                    )
                )

        @property
        def core(self):
            return self._core.value

        @core.setter
        def core(self, value):
            if isinstance(value, (str,)):
                self._core = _zivid.FrameInfo.SoftwareVersion.Core(value)
            else:
                raise TypeError(
                    "Unsupported type, expected: str, got {value_type}".format(
                        value_type=type(value)
                    )
                )

        def __eq__(self, other):
            if self._core == other._core:
                return True
            return False

        def __str__(self):
            return str(
                zivid._frame_info_converter.to_internal_frame_info_software_version(
                    self
                )
            )

    def __init__(
        self, time_stamp=_zivid.FrameInfo().TimeStamp().value, software_version=None,
    ):

        if isinstance(time_stamp, (datetime.datetime,)):
            if time_stamp < datetime.datetime(1970, 1, 1):
                raise ValueError(
                    "Unsupported time stamp: '{time_stamp}', time stamp can only be set to a time point after January 1st, 1970".format(
                        time_stamp=time_stamp
                    )
                )
            self._time_stamp = _zivid.FrameInfo.TimeStamp(time_stamp)
        else:
            raise TypeError(
                "Unsupported type, expected: (datetime.datetime,), got {value_type}".format(
                    value_type=type(time_stamp)
                )
            )
        if software_version is None:
            software_version = zivid.FrameInfo.SoftwareVersion()
        if not isinstance(software_version, zivid.FrameInfo.SoftwareVersion):
            raise TypeError(
                "Unsupported type: {value}".format(value=type(software_version))
            )
        self._software_version = software_version

    @property
    def time_stamp(self):
        return self._time_stamp.value

    @property
    def software_version(self):
        return self._software_version

    @time_stamp.setter
    def time_stamp(self, value):
        if isinstance(value, (datetime.datetime,)):
            if value < datetime.datetime(1970, 1, 1):
                raise ValueError(
                    "Unsupported time stamp: '{value}', time stamp can only be set to a time point after January 1st, 1970".format(
                        value=value
                    )
                )
            self._time_stamp = _zivid.FrameInfo.TimeStamp(value)
        else:
            raise TypeError(
                "Unsupported type, expected: datetime.datetime, got {value_type}".format(
                    value_type=type(value)
                )
            )

    @software_version.setter
    def software_version(self, value):
        if not isinstance(value, zivid.FrameInfo.SoftwareVersion):
            raise TypeError("Unsupported type {value}".format(value=type(value)))
        self._software_version = value

    def __eq__(self, other):
        if (
            self._time_stamp == other._time_stamp
            and self._software_version == other._software_version
        ):
            return True
        return False

    def __str__(self):
        return str(zivid._frame_info_converter.to_internal_frame_info(self))



"""Auto generated, do not edit."""
import zivid
import _zivid


def to_settings2_d_acquisition(internal_acquisition):
    return zivid.Settings2D.Acquisition(
        aperture=internal_acquisition.aperture.value,
        brightness=internal_acquisition.brightness.value,
        exposure_time=internal_acquisition.exposure_time.value,
        gain=internal_acquisition.gain.value,
    )


def to_settings2_d_processing_color_balance(internal_balance):
    return zivid.Settings2D.Processing.Color.Balance(
        blue=internal_balance.blue.value,
        green=internal_balance.green.value,
        red=internal_balance.red.value,
    )


def to_settings2_d_processing_color(internal_color):
    return zivid.Settings2D.Processing.Color(
        balance=to_settings2_d_processing_color_balance(internal_color.balance),
        gamma=internal_color.gamma.value,
    )


def to_settings2_d_processing(internal_processing):
    return zivid.Settings2D.Processing(
        color=to_settings2_d_processing_color(internal_processing.color),
    )


def to_settings2_d(internal_settings2_d):
    return zivid.Settings2D(
        processing=to_settings2_d_processing(internal_settings2_d.processing),
        acquisitions=[
            to_settings2_d_acquisition(element)
            for element in internal_settings2_d.acquisitions.value
        ],
    )


def to_internal_settings2_d_acquisition(acquisition):
    internal_acquisition = _zivid.Settings2D.Acquisition()

    internal_acquisition.aperture = _zivid.Settings2D.Acquisition.Aperture(
        acquisition.aperture
    )
    internal_acquisition.brightness = _zivid.Settings2D.Acquisition.Brightness(
        acquisition.brightness
    )
    internal_acquisition.exposure_time = _zivid.Settings2D.Acquisition.ExposureTime(
        acquisition.exposure_time
    )
    internal_acquisition.gain = _zivid.Settings2D.Acquisition.Gain(acquisition.gain)

    return internal_acquisition


def to_internal_settings2_d_processing_color_balance(balance):
    internal_balance = _zivid.Settings2D.Processing.Color.Balance()

    internal_balance.blue = _zivid.Settings2D.Processing.Color.Balance.Blue(
        balance.blue
    )
    internal_balance.green = _zivid.Settings2D.Processing.Color.Balance.Green(
        balance.green
    )
    internal_balance.red = _zivid.Settings2D.Processing.Color.Balance.Red(balance.red)

    return internal_balance


def to_internal_settings2_d_processing_color(color):
    internal_color = _zivid.Settings2D.Processing.Color()

    internal_color.gamma = _zivid.Settings2D.Processing.Color.Gamma(color.gamma)
    internal_color.balance = to_internal_settings2_d_processing_color_balance(
        color.balance
    )
    return internal_color


def to_internal_settings2_d_processing(processing):
    internal_processing = _zivid.Settings2D.Processing()

    internal_processing.color = to_internal_settings2_d_processing_color(
        processing.color
    )
    return internal_processing


def to_internal_settings2_d(settings2_d):
    internal_settings2_d = _zivid.Settings2D()
    internal_settings2_d.processing = to_internal_settings2_d_processing(
        settings2_d.processing
    )
    temp = _zivid.Settings2D().Acquisitions()
    for acq in settings2_d.acquisitions:
        temp.append(to_internal_settings2_d_acquisition(acq))
    internal_settings2_d.acquisitions = temp

    return internal_settings2_d



"""Auto generated, do not edit."""
import datetime

import _zivid
import zivid._settings_converter as _settings_converter
from zivid._capture_assistant_suggest_settings_parameters_converter import (
    to_internal_capture_assistant_suggest_settings_parameters,
)


class SuggestSettingsParameters:
    """Class representing parameters to the Capture Assistant.

    An instance of this class is used as an argument to suggest_settings() in order
    to specify parameters and constraints to the capture assistant.
    """

    class AmbientLightFrequency:  # pylint: disable=too-few-public-methods
        """Optional choice for adapting to ambient light frequency.

        May help remove ripple artifacts caused by strong ambient light.
        """

        hz50 = "hz50"
        hz60 = "hz60"
        none = "none"

        _valid_values = {
            "hz50": _zivid.capture_assistant.SuggestSettingsParameters.AmbientLightFrequency.hz50,
            "hz60": _zivid.capture_assistant.SuggestSettingsParameters.AmbientLightFrequency.hz60,
            "none": _zivid.capture_assistant.SuggestSettingsParameters.AmbientLightFrequency.none,
        }

        @classmethod
        def valid_values(cls):
            """Get list of allowed values.

            Returns:
                List of strings
            """
            return list(cls._valid_values.keys())

    def __init__(
        self,
        ambient_light_frequency=_zivid.capture_assistant.SuggestSettingsParameters()
        .AmbientLightFrequency()
        .value,
        max_capture_time=_zivid.capture_assistant.SuggestSettingsParameters()
        .MaxCaptureTime()
        .value,
    ):
        """Initialize a SuggestSettingsParameters.

        Pass this object to zivid.capture_assistant.suggest_settings() to run the Capture Assistant.

        Args:
            ambient_light_frequency: Optional ambient light adaptation ("none", "hz50" or "hz60")
            max_capture_time: A datetime.timedelta specifying maximum allowed HDR capture time

        Raises:
            TypeError: If one of the arguments is of the wrong type
        """
        if isinstance(
            ambient_light_frequency,
            _zivid.capture_assistant.SuggestSettingsParameters.AmbientLightFrequency.enum,
        ):
            self._ambient_light_frequency = ambient_light_frequency
        elif isinstance(ambient_light_frequency, (str,)):
            self._ambient_light_frequency = _convert_to_internal(
                ambient_light_frequency
            )
        else:
            raise TypeError(
                "Unsupported type, expected: str, got {value_type}".format(
                    value_type=type(ambient_light_frequency)
                )
            )
        if isinstance(max_capture_time, (datetime.timedelta,)):
            self._max_capture_time = _zivid.capture_assistant.SuggestSettingsParameters.MaxCaptureTime(
                max_capture_time
            )
        else:
            raise TypeError(
                "Unsupported type, expected: (datetime.timedelta,), got {value_type}".format(
                    value_type=type(max_capture_time)
                )
            )

    @property
    def ambient_light_frequency(self):
        """Get the contained ambient light adaptation setting.

        Returns:
            A string, among the valid values of AmbientLightFrequency

        Raises:
            ValueError: If the object contains an invalid ambient light frequency setting
        """
        for (
            key,
            value,
        ) in (
            SuggestSettingsParameters.AmbientLightFrequency._valid_values.items()  # pylint: disable=protected-access
        ):
            if value == self._ambient_light_frequency:
                return key
        raise ValueError(
            "Unsupported value {value}".format(value=self._ambient_light_frequency)
        )

    @property
    def max_capture_time(self):
        """Get the contained max capture time setting.

        Returns:
            A datetime.timedelta object
        """
        return self._max_capture_time.value

    @ambient_light_frequency.setter
    def ambient_light_frequency(self, value):
        if isinstance(value, (str,)):
            self._ambient_light_frequency = _convert_to_internal(value)
        else:
            raise TypeError(
                "Unsupported type, expected: str, got {value_type}".format(
                    value_type=type(value)
                )
            )

    @max_capture_time.setter
    def max_capture_time(self, value):
        if isinstance(value, (datetime.timedelta,)):
            self._max_capture_time = _zivid.capture_assistant.SuggestSettingsParameters.MaxCaptureTime(
                value
            )
        else:
            raise TypeError(
                "Unsupported type, expected: (datetime.timedelta,), got {value_type}".format(
                    value_type=type(value)
                )
            )

    def __eq__(self, other):
        if (
            self._ambient_light_frequency == other._ambient_light_frequency
            and self._max_capture_time == other._max_capture_time
        ):
            return True
        return False

    def __str__(self):
        return str(to_internal_capture_assistant_suggest_settings_parameters(self))


def _convert_to_internal(ambient_light_frequency):
    if isinstance(ambient_light_frequency, str):
        if (
            ambient_light_frequency
            not in SuggestSettingsParameters.AmbientLightFrequency._valid_values  # pylint: disable=protected-access
        ):
            raise TypeError(
                "Unsupported value {value}".format(value=ambient_light_frequency)
            )
        ambient_light_frequency = SuggestSettingsParameters.AmbientLightFrequency._valid_values[  # pylint: disable=protected-access
            ambient_light_frequency
        ]
        if not isinstance(
            ambient_light_frequency,
            _zivid.capture_assistant.SuggestSettingsParameters.AmbientLightFrequency.enum,
        ):
            raise TypeError(
                "Unsupported type: {value}".format(value=type(ambient_light_frequency))
            )
        return ambient_light_frequency
    raise TypeError(
        "Unsupported type: {value}".format(value=type(ambient_light_frequency))
    )


def suggest_settings(camera, suggest_settings_parameters):
    """Find settings for the current scene based on given parameters.

    The suggested settings returned from this function should be passed into
    camera.capture() to capture and retrieve the Frame containing a point cloud.

    Args:
        camera: A Camera instance
        suggest_settings_parameters: A SuggestSettingsParameters instance

    Returns:
        A Settings instance optimized for the current scene
    """
    internal_settings = _zivid.capture_assistant.suggest_settings(
        camera._Camera__impl,  # pylint: disable=protected-access
        to_internal_capture_assistant_suggest_settings_parameters(
            suggest_settings_parameters
        ),
    )
    return _settings_converter.to_settings(internal_settings)



from datetime import datetime
import pytest
import zivid


def test_time_stamp(frame_info):
    time_stamp = frame_info.time_stamp
    assert time_stamp
    assert isinstance(time_stamp, datetime)


def test_software_version(frame_info):
    software_version = frame_info.software_version
    assert software_version
    assert isinstance(software_version, zivid.frame_info.FrameInfo.SoftwareVersion)
    assert software_version.core
    assert isinstance(software_version.core, str)


def test_set_time_stamp(frame_info):
    assert isinstance(frame_info.time_stamp, datetime)
    assert isinstance(str(frame_info.time_stamp), str)
    new_time_stamp = datetime(1992, 2, 7)
    frame_info.time_stamp = new_time_stamp
    assert isinstance(str(frame_info.time_stamp), str)
    assert isinstance(frame_info.time_stamp, datetime)
    assert frame_info.time_stamp == new_time_stamp


def test_set_illegal_time_stamp(frame_info):
    with pytest.raises(ValueError):
        frame_info.time_stamp = datetime(1337, 1, 1)
    with pytest.raises(ValueError):
        frame_info.time_stamp = datetime(1969, 12, 31)


def test_init_illegal_time_stamp():
    with pytest.raises(ValueError):
        _ = zivid.FrameInfo(time_stamp=datetime(1969, 12, 31))
    with pytest.raises(ValueError):
        _ = zivid.FrameInfo(time_stamp=datetime(1337, 1, 1))
